#!/usr/bin/python

__doc__ = "Macromedia Generator Base Classes"
__version__ = "0.0.1"

valid_generator_types = {'swf':1, 'gif':1, 'png':1, 'qtm':1, \
			 'jpg':1, 'txt':2, 'smap':2, 'cmap':2 }

import string


class GeneratorBase:
    """
    Base Class for a Generator instance.
    The purpose of this class is to allow the user to create a reference
    to all the files needed for generation and call them at runtime as needed.
    """
    def __init__(self, template_dir='/tmp', template_name='template.swt',      \
		 input_file='input.txt', out_dir='/tmp', 		       \
		 out_filenamebase='genfile', output_types=['jpg', 'gif'],      \
		 addl_options='debug 3',	       \
		 generator_path='/usr/local/generator2/generator/generate'):

	self.template_dir = template_dir # the directory where the template is
	self.template_name = template_name # the name of the template to use
	self.input_file = input_file # input text file 
	self.out_dir = out_dir # directory for output files
	self.out_filenamebase = out_filenamebase # base name for output files
	self.output_types = output_types # list of output file formats
	self.addl_options = addl_options # for other flags like -debug or -log
	self.generator_path = generator_path # path to the executable

    def ReIndexInputs(self):

	infilename = '%s/%s' % (self.template_dir, self.input_file)
	try:
		infile = open(infilename, 'r' )
	except:
		return "Could not open input %s for reading." % infilename

	self.namevalueDict = {}

	for line in infile.readlines():
		rname, rvalue = string.split(line, ",")

		if rname != 'name':
			self.namevalueDict[rname] = rvalue

	return "Indexing completed.  %d items indexed." % len(self.namevalueDict)

    def Generate(self):
	import os

	errors = []


	gen_command = "%s " % self.generator_path

	if self.addl_options != '':
		if self.addl_options[:1] != '-':
				gen_command = gen_command + '-'
		gen_command = gen_command + self.addl_options + " "

	for type in self.output_types:
	    if valid_generator_types.has_key(type):
		gen_command = gen_command + "-%s %s/%s.%s " % \
		   ( type, self.out_dir, self.out_filenamebase, type )
	    else:
		errors.append('Error: could not output the file type %s' % type)

	if errors != []:
		return string.join(errors, '\n')

	gen_command = gen_command + "%s/%s" % \
				(self.template_dir, self.template_name )

	results = os.popen(gen_command).read()
	return ["<B>Generating</B>", gen_command, results, 'Generation Completed']

